
## CATO-CLI - query.accountSnapshot:
[Click here](https://api.catonetworks.com/documentation/#query-query.accountSnapshot) for documentation on this operation.

### Usage for query.accountSnapshot:

```bash
catocli query accountSnapshot -h

catocli query accountSnapshot <json>

catocli query accountSnapshot "$(cat < query.accountSnapshot.json)"

#### Operation Arguments for query.accountSnapshot ####

`accountID` [ID] - (required) Unique Identifier of Account.    
